@@ -17,12 +17,13 @@ use Class::Accessor::Lite
         schema_class
         suppress_row_objects
         sql_builder
+        sql_comment
         owner_pid
         driver_name
     )]
 ;
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 sub load_plugin {
     my ($class, $pkg, $opt) = @_;
@@ -111,7 +112,7 @@ sub connect {
 sub reconnect {
     my $self = shift;
 
-    if ($self->txn_manager->in_transaction) {
+    if ($self->in_transaction) {
         Carp::confess("Detected disconnected database during a transaction. Refusing to proceed");
     }
 
@@ -158,6 +159,16 @@ sub _execute {
 
     my $sth;
     eval {
+        if ($ENV{TENG_SQL_COMMENT} || $self->sql_comment) {
+            my $i = 1; # optimize, as we would *NEVER* be called
+            while ( my (@caller) = caller($i++) ) {
+                next if ( $caller[0]->isa( __PACKAGE__ ) );
+                my $comment = "$caller[1] at line $caller[2]";
+                $comment =~ s/\*\// /g;
+                $sql = "/* $comment */\n$sql";
+                last;
+            }
+        }
         $sth = $self->dbh->prepare($sql);
         $sth->execute(@{$binds || []});
     };
@@ -267,6 +278,11 @@ sub txn_manager  {
     $self->{txn_manager} ||= DBIx::TransactionManager->new($self->dbh);
 }
 
+sub in_transaction {
+    my $self = shift;
+    $self->{txn_manager} ? $self->{txn_manager}->in_transaction : undef;
+}
+
 sub txn_scope    { $_[0]->txn_manager->txn_scope    }
 sub txn_begin    { $_[0]->txn_manager->txn_begin    }
 sub txn_rollback { $_[0]->txn_manager->txn_rollback }
