@@ -5,35 +5,17 @@ use utf8;
 
 our @EXPORT = qw/bulk_insert/;
 
-warn "IMPORTANT: Teng::Plugin::BulkInsert is DEPRECATED AND *WILL* BE REMOVED. DO NOT USE.\n";
-
 sub bulk_insert {
-    my ($self, $table_name, $args) = @_;
-
-    return unless scalar(@{$args||[]});
+    my ($self, $table, $args) = @_;
 
     if ($self->dbh->{Driver}->{Name} eq 'mysql') {
-        my $table = $self->schema->get_table($table_name);
-        if (! $table) {
-            Carp::croak( "Table definition for $table_name does not exist (Did you declare it in our schema?)" );
-        }
-
-        if ( $table->has_deflators ) {
-            for my $row (@$args) {
-                for my $col (keys %{$row}) {
-                    $row->{$col} = $table->call_deflate($col, $row->{$col});
-                }
-            }
-        }
-
-        my ($sql, @binds) = $self->sql_builder->insert_multi( $table_name, $args );
-        $self->_execute($sql, \@binds);
+        $self->insert_multi($table, $args);
     } else {
         # use transaction for better performance and atomicity.
         my $txn = $self->txn_scope();
         for my $arg (@$args) {
             # do not run trigger for consistency with mysql.
-            $self->insert($table_name, $arg);
+            $self->insert($table, $arg);
         }
         $txn->commit;
     }
@@ -44,7 +26,7 @@ __END__
 
 =head1 NAME
 
-Teng::Plugin::BulkInsert - (DEPRECATED) bulk insert helper
+Teng::Plugin::BulkInsert - bulk insert helper
 
 =head1 PROVIDED METHODS
 
